==> tecfy_core_package-0.1.95.tar.gz: lib/views/components/entity_filter/property_filter.componenet.dart <==
part of tecfy_core_client_package;

class PorpertyFilterComponent extends StatefulWidget {
  final Property property;
  final dynamic value;
  final void Function(dynamic) onChange;
  PorpertyFilterComponent({this.property, this.onChange, this.value});
  @override
  _PorpertyFilterComponentState createState() =>
      _PorpertyFilterComponentState();
}

class _PorpertyFilterComponentState extends State<PorpertyFilterComponent> {
  TextEditingController textController;
  FocusNode focusNode;
  dynamic _initValue;
  bool _isVisible = true;
  @override
  void initState() {
    init();
    super.initState();
  }

  init() {
    _initValue = widget.value;
    if (widget.property.propertyType == PropertyTypes.Text ||
        widget.property.propertyType == PropertyTypes.Number) {
      if (textController == null) {
        textController =
            TextEditingController(text: widget.value?.toString() ?? '');
        focusNode = FocusNode();
        textController.addListener(() {
          submitChages();
        });
      } else {
        textController.text = _initValue?.toString() ?? '';
      }
    }
  }

  submitChages() {
    if (widget.onChange == null) return;
    if (widget.property.propertyType == PropertyTypes.Text) {
      _initValue = textController.text;
      widget.onChange(textController.text);
    }
    if (widget.property.propertyType == PropertyTypes.Number) {
      _initValue = num.tryParse(textController.text);
      widget.onChange(_initValue);
    }
  }

  @override
  Widget build(BuildContext context) {
    // widget.property.isVisible(widget.data, widget.entity).then((isVisible) {
    //   if (isVisible != _isVisible) {
    //     _isVisible = isVisible;
    //     setState(() {});
    //   }
    // });

    if (!_isVisible || !widget.property.isEdit) return Container();

    if (_initValue != widget.value) init();

    switch (widget.property.propertyType) {
      case PropertyTypes.Dropdown:
        return DropdownAdvancedEntity(
          (widget.property as PropertyDropdown).entityName,
          label: widget.property.name,
          entity: EntityService.getEntity(
              (widget.property as PropertyDropdown).entityName),
          url: (widget.property as PropertyDropdown).dropdownUrl,
          property: (widget.property as PropertyDropdown),
          isRequired: widget.property.isRequired,
          data: {widget.property.dbName: widget.value},
          onChanged: (v, data) => widget.onChange(v),
        );

      case PropertyTypes.Text:
        if ((widget.property as PropertyText).isPassword) return Container();
        return AppTextFormField(
          textDirection: LocalConfigService.isArabic &&
                  !(widget.property as PropertyText).isEmail
              ? TextDirection.rtl
              : TextDirection.ltr,
          labelText: widget.property.name,
          focusNode: focusNode,
          controller: textController,
          onFieldSubmitted: (v) => focusNode?.unfocus(),
          textInputAction: TextInputAction.next,
          isRequired: widget.property.isRequired,
          keyboardType: (widget.property as PropertyText).isEmail
              ? TextInputType.emailAddress
              : TextInputType.text,
          maxLines: 1,
          onEditingComplete: submitChages,
        );
      case PropertyTypes.Number:
        return AppTextFormField(
            labelText: widget.property.name,
            controller: textController,
            focusNode: focusNode,
            isRequired: widget.property.isRequired,
            onFieldSubmitted: (v) => focusNode?.unfocus(),
            textInputAction: TextInputAction.next,
            keyboardType: TextInputType.number,
            onEditingComplete: submitChages);
      // case PropertyTypes.Boolean:
      //   return AppCheckBox(
      //       label: widget.property.name,
      //       initalValue: _initValue,
      //       onChanged: (v) {
      //         widget.onChange(v);
      //       });

      case PropertyTypes.Color:
        return ColorPropertyComponenet(
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            label: widget.property.name,
            onChanged: (v) => widget.onChange(v));

      case PropertyTypes.Date:
        return DateProperty(
            label: widget.property.name,
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            onChanged: (v) {
              widget.onChange(v);
            });

      default:
        return Container();
    }
  }
}

==> tecfy_core_package-1.0.0.tar.gz: lib/views/components/entity_filter/property_filter.componenet.dart <==
part of tecfy_core_client_package;

class PorpertyFilterComponent extends StatefulWidget {
  final Property property;
  final dynamic value;
  final void Function(dynamic)? onChange;
  PorpertyFilterComponent({required this.property, this.onChange, this.value});
  @override
  _PorpertyFilterComponentState createState() =>
      _PorpertyFilterComponentState();
}

class _PorpertyFilterComponentState extends State<PorpertyFilterComponent> {
  late TextEditingController textController;
  late FocusNode focusNode;
  dynamic _initValue;
  bool _isVisible = true;
  @override
  void initState() {
    init();
    super.initState();
  }

  init() {
    _initValue = widget.value;
    if (widget.property.propertyType == PropertyTypes.Text ||
        widget.property.propertyType == PropertyTypes.Number) {
      if (textController == null) {
        textController =
            TextEditingController(text: widget.value?.toString() ?? '');
        focusNode = FocusNode();
        textController.addListener(() {
          submitChages();
        });
      } else {
        textController.text = _initValue?.toString() ?? '';
      }
    }
  }

  submitChages() {
    if (widget.onChange == null) return;
    if (widget.property.propertyType == PropertyTypes.Text) {
      _initValue = textController.text;
      widget.onChange?.call(textController.text);
    }
    if (widget.property.propertyType == PropertyTypes.Number) {
      _initValue = num.tryParse(textController.text);
      widget.onChange?.call(_initValue);
    }
  }

  @override
  Widget build(BuildContext context) {
    // widget.property.isVisible(widget.data, widget.entity).then((isVisible) {
    //   if (isVisible != _isVisible) {
    //     _isVisible = isVisible;
    //     setState(() {});
    //   }
    // });

    if (!_isVisible || !widget.property.isEdit) return Container();

    if (_initValue != widget.value) init();

    switch (widget.property.propertyType) {
      case PropertyTypes.Dropdown:
        return DropdownAdvancedEntity(
          (widget.property as PropertyDropdown).entityName,
          label: widget.property.name,
          entity: EntityService.getEntity(
              (widget.property as PropertyDropdown).entityName)!,
          url: (widget.property as PropertyDropdown).dropdownUrl,
          property: (widget.property as PropertyDropdown),
          isRequired: widget.property.isRequired,
          data: {widget.property.dbName: widget.value},
          onChanged: (v, data) => widget.onChange?.call(v),
        );

      case PropertyTypes.Text:
        if ((widget.property as PropertyText).isPassword) return Container();
        return AppTextFormField(
          textDirection: LocalConfigService.isArabic &&
                  !(widget.property as PropertyText).isEmail
              ? TextDirection.rtl
              : TextDirection.ltr,
          labelText: widget.property.name,
          focusNode: focusNode,
          controller: textController,
          onFieldSubmitted: (v) => focusNode?.unfocus(),
          textInputAction: TextInputAction.next,
          isRequired: widget.property.isRequired,
          keyboardType: (widget.property as PropertyText).isEmail
              ? TextInputType.emailAddress
              : TextInputType.text,
          maxLines: 1,
          onEditingComplete: submitChages,
        );
      case PropertyTypes.Number:
        return AppTextFormField(
            labelText: widget.property.name,
            controller: textController,
            focusNode: focusNode,
            isRequired: widget.property.isRequired,
            onFieldSubmitted: (v) => focusNode?.unfocus(),
            textInputAction: TextInputAction.next,
            keyboardType: TextInputType.number,
            onEditingComplete: submitChages);
      // case PropertyTypes.Boolean:
      //   return AppCheckBox(
      //       label: widget.property.name,
      //       initalValue: _initValue,
      //       onChanged: (v) {
      //         widget.onChange(v);
      //       });

      case PropertyTypes.Color:
        return ColorPropertyComponenet(
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            label: widget.property.name,
            onChanged: (v) => widget.onChange?.call(v));

      case PropertyTypes.Date:
        return DateProperty(
            label: widget.property.name,
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            onChanged: (v) {
              widget.onChange?.call(v);
            });

      default:
        return Container();
    }
  }
}
